/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Object } from "../definitions/Object";
import { Links } from "../definitions/Links";
import { Author } from "../definitions/Author";
import { Committer } from "../definitions/Committer";
export declare type BaseCommit = Object & {
    rendered?: {
        message?: {
            /**
             * The text as it was typed by a user.
             */
            raw?: string;
            /**
             * The type of markup language the raw content is to be interpreted in.
             */
            markup?: string;
            /**
             * The user's content rendered as HTML.
             */
            html?: string;
            type?: string;
        };
    };
    links?: Links;
    hash?: string;
    date?: string;
    author?: Author;
    message?: string;
    summary?: {
        /**
         * The text as it was typed by a user.
         */
        raw?: string;
        /**
         * The type of markup language the raw content is to be interpreted in.
         */
        markup?: "markdown" | "creole" | "plaintext";
        /**
         * The user's content rendered as HTML.
         */
        html?: string;
        type?: string;
    };
    parents?: Array<BaseCommit>;
    properties?: {
        [x: string]: any;
    };
    committer?: Committer;
    repository?: {
        links?: {
            /**
             * A link to a resource related to this object.
             */
            self?: {
                href?: string;
                name?: string;
            };
            /**
             * A link to a resource related to this object.
             */
            html?: {
                href?: string;
                name?: string;
            };
            /**
             * A link to a resource related to this object.
             */
            avatar?: {
                href?: string;
                name?: string;
            };
        };
        /**
         * The concatenation of the repository owner's username and the slugified name, e.g. "evzijst/interruptingcow". This is the same string used in Bitbucket URLs.
         */
        full_name?: string;
        name?: string;
        /**
         * The repository's immutable id. This can be used as a substitute for the slug segment in URLs. Doing this guarantees your URLs will survive renaming of the repository by its owner, or even transfer of the repository to a different user.
         */
        uuid?: string;
        type?: string;
    };
    [x: string]: any;
};
//# sourceMappingURL=BaseCommit.d.ts.map