/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Object } from "../definitions/Object";
import { Account } from "../definitions/Account";
import { Group } from "../definitions/Group";
export declare type Branchrestriction = Object & {
    links?: {
        /**
         * A link to a resource related to this object.
         */
        self?: {
            href?: string;
            name?: string;
        };
    };
    /**
     * The branch restriction status' id.
     */
    id?: number;
    /**
     * The type of restriction that is being applied.
     */
    kind: "require_tasks_to_be_completed" | "allow_auto_merge_when_builds_pass" | "require_passing_builds_to_merge" | "force" | "require_all_dependencies_merged" | "require_commits_behind" | "restrict_merges" | "enforce_merge_checks" | "reset_pullrequest_changes_requested_on_change" | "require_no_changes_requested" | "smart_reset_pullrequest_approvals" | "push" | "require_approvals_to_merge" | "require_default_reviewer_approvals_to_merge" | "reset_pullrequest_approvals_on_change" | "delete" | "allow_auto_merge_when_builds_pass" | "require_all_comments_resolved";
    /**
     * Indicates how the restriction is matched against a branch. The default is `glob`.
     */
    branch_match_kind: "branching_model" | "glob";
    /**
     * Apply the restriction to branches of this type. Active when `branch_match_kind` is `branching_model`. The branch type will be calculated using the branching model configured for the repository.
     */
    branch_type?: "feature" | "bugfix" | "release" | "hotfix" | "development" | "production";
    /**
     * Apply the restriction to branches that match this pattern. Active when `branch_match_kind` is `glob`. Will be empty when `branch_match_kind` is `branching_model`.
     */
    pattern: string;
    users?: Array<Account>;
    groups?: Array<Group>;
    /**
  * Value with kind-specific semantics:
  
  * `require_approvals_to_merge` uses it to require a minimum number of approvals on a PR.
  
  * `require_default_reviewer_approvals_to_merge` uses it to require a minimum number of approvals from default reviewers on a PR.
  
  * `require_passing_builds_to_merge` uses it to require a minimum number of passing builds.
  
  * `require_commits_behind` uses it to require the current branch is up to a maximum number of commits behind it destination.
  */
    value?: number | null;
    [x: string]: any;
};
//# sourceMappingURL=Branchrestriction.d.ts.map