/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ObjectAsResponse } from "../definitions/ObjectAsResponse";
import { RepositoryAsResponse } from "../definitions/RepositoryAsResponse";
import { CommitAsResponse } from "../definitions/CommitAsResponse";
export declare type CommitstatusAsResponse = ObjectAsResponse & {
    links?: {
        /**
         * A link to a resource related to this object.
         */
        self?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        commit?: {
            href?: string;
            name?: string;
        };
    };
    /**
     * The commit status' id.
     */
    uuid?: string;
    /**
  * An identifier for the status that's unique to
          its type (current "build" is the only supported type) and the vendor,
          e.g. BB-DEPLOY
  */
    key?: string;
    /**
  *
  The name of the ref that pointed to this commit at the time the status
  object was created. Note that this the ref may since have moved off of
  the commit. This optional field can be useful for build systems whose
  build triggers and configuration are branch-dependent (e.g. a Pipeline
  build).
  It is legitimate for this field to not be set, or even apply (e.g. a
  static linting job).
  */
    refname?: string | null;
    /**
     * A URL linking back to the vendor or build system, for providing more information about whatever process produced this status. Accepts context variables `repository` and `commit` that Bitbucket will evaluate at runtime whenever at runtime. For example, one could use https://foo.com/builds/{repository.full_name} which Bitbucket will turn into https://foo.com/builds/foo/bar at render time.
     */
    url?: string;
    /**
     * Provides some indication of the status of this commit
     */
    state?: "SUCCESSFUL" | "FAILED" | "INPROGRESS" | "STOPPED";
    /**
     * An identifier for the build itself, e.g. BB-DEPLOY-1
     */
    name?: string;
    /**
     * A description of the build (e.g. "Unit tests in Bamboo")
     */
    description?: string;
    created_on?: string;
    updated_on?: string;
    repository?: RepositoryAsResponse;
    commit?: CommitAsResponse;
    [x: string]: any;
};
//# sourceMappingURL=CommitstatusAsResponse.d.ts.map