/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ObjectAsResponse } from "../definitions/ObjectAsResponse";
import { AccountAsResponse } from "../definitions/AccountAsResponse";
import { PullrequestEndpointAsResponse } from "../definitions/PullrequestEndpointAsResponse";
import { ParticipantAsResponse } from "../definitions/ParticipantAsResponse";
export declare type PullrequestAsResponse = ObjectAsResponse & {
    links?: {
        /**
         * A link to a resource related to this object.
         */
        self?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        html?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        commits?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        approve?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        diff?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        diffstat?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        comments?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        activity?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        merge?: {
            href?: string;
            name?: string;
        };
        /**
         * A link to a resource related to this object.
         */
        decline?: {
            href?: string;
            name?: string;
        };
    };
    /**
     * The pull request's unique ID. Note that pull request IDs are only unique within their associated repository.
     */
    id?: number;
    /**
     * Title of the pull request.
     */
    title?: string;
    /**
     * User provided pull request text, interpreted in a markup language and rendered in HTML
     */
    rendered?: {
        title?: {
            /**
             * The text as it was typed by a user.
             */
            raw?: string;
            /**
             * The type of markup language the raw content is to be interpreted in.
             */
            markup?: "markdown" | "creole" | "plaintext";
            /**
             * The user's content rendered as HTML.
             */
            html?: string;
        };
        description?: {
            /**
             * The text as it was typed by a user.
             */
            raw?: string;
            /**
             * The type of markup language the raw content is to be interpreted in.
             */
            markup?: "markdown" | "creole" | "plaintext";
            /**
             * The user's content rendered as HTML.
             */
            html?: string;
        };
        reason?: {
            /**
             * The text as it was typed by a user.
             */
            raw?: string;
            /**
             * The type of markup language the raw content is to be interpreted in.
             */
            markup?: "markdown" | "creole" | "plaintext";
            /**
             * The user's content rendered as HTML.
             */
            html?: string;
        };
    };
    summary?: {
        /**
         * The text as it was typed by a user.
         */
        raw?: string;
        /**
         * The type of markup language the raw content is to be interpreted in.
         */
        markup?: "markdown" | "creole" | "plaintext";
        /**
         * The user's content rendered as HTML.
         */
        html?: string;
    };
    /**
     * The pull request's current status.
     */
    state?: "OPEN" | "MERGED" | "DECLINED" | "SUPERSEDED";
    author?: AccountAsResponse;
    source?: PullrequestEndpointAsResponse;
    destination?: PullrequestEndpointAsResponse;
    merge_commit?: {
        hash?: string;
    };
    /**
     * The number of comments for a specific pull request.
     */
    comment_count?: number;
    /**
     * The number of open tasks for a specific pull request.
     */
    task_count?: number;
    /**
     * A boolean flag indicating if merging the pull request closes the source branch.
     */
    close_source_branch?: boolean;
    closed_by?: AccountAsResponse;
    /**
     * Explains why a pull request was declined. This field is only applicable to pull requests in rejected state.
     */
    reason?: string;
    /**
     * The ISO8601 timestamp the request was created.
     */
    created_on?: string;
    /**
     * The ISO8601 timestamp the request was last updated.
     */
    updated_on?: string;
    /**
     * The list of users that were added as reviewers on this pull request when it was created. For performance reasons, the API only includes this list on a pull request's `self` URL.
     */
    reviewers?: Array<AccountAsResponse>;
    /**
  *         The list of users that are collaborating on this pull request.
          Collaborators are user that:
  
          * are added to the pull request as a reviewer (part of the reviewers
            list)
          * are not explicit reviewers, but have commented on the pull request
          * are not explicit reviewers, but have approved the pull request
  
          Each user is wrapped in an object that indicates the user's role and
          whether they have approved the pull request. For performance reasons,
          the API only returns this list when an API requests a pull request by
          id.
          
  */
    participants?: Array<ParticipantAsResponse>;
    [x: string]: any;
};
//# sourceMappingURL=PullrequestAsResponse.d.ts.map