/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedBranchesAsResponse } from "../../definitions/PaginatedBranchesAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BranchAsResponse } from "../../definitions/BranchAsResponse";
export interface GetRepositoryOpenBranchesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  *
  Query string to narrow down the response as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
   Example:`target.hash="1e9e09996d3f636c7254942bdaf15c4fcd4f0fd4"`
  */
    q?: string;
    /**
  *
  Field by which the results should be sorted as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering). The `name`
  field is handled specially for branches in that, if specified as the sort field, it
  uses a natural sort order instead of the default lexicographical sort order. For example,
  it will return ['branch1', 'branch2', 'branch10'] instead of ['branch1', 'branch10', 'branch2'].
  */
    sort?: string;
}
declare type GetRepositoryOpenBranchesResponseOKType = PaginatedBranchesAsResponse;
export interface GetRepositoryOpenBranchesResponseOK extends GetRepositoryOpenBranchesResponseOKType {
}
declare type GetRepositoryOpenBranchesResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryOpenBranchesResponseError extends GetRepositoryOpenBranchesResponseErrorType {
}
export interface CreateRepositoryBranchRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * The target commit.
         */
        target: {
            /**
                   * This endpoint does support using short hash prefixes for the commit hash,
                   but it may return a 400 response if the provided prefix is ambiguous.
                   Using a full commit hash is the preferred approach.
                   */
            hash: string;
        };
        /**
         * The branch name should not include any prefixes (e.g. refs/heads).
         */
        name: string;
    };
}
export interface CreateRepositoryBranchResponseOK extends BranchAsResponse {
}
export interface CreateRepositoryBranchResponseError extends ErrorAsResponse {
}
export interface GetRepositoryBranchRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the branch.
     */
    name: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryBranchResponseOKType = BranchAsResponse;
export interface GetRepositoryBranchResponseOK extends GetRepositoryBranchResponseOKType {
}
declare type GetRepositoryBranchResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryBranchResponseError extends GetRepositoryBranchResponseErrorType {
}
export interface DeleteRepositoryBranchRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the branch.
     */
    name: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
export declare type DeleteRepositoryBranchResponseOK = undefined;
declare type DeleteRepositoryBranchResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface DeleteRepositoryBranchResponseError extends DeleteRepositoryBranchResponseErrorType {
}
export {};
//# sourceMappingURL=branch.d.ts.map