/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedBranchrestrictionsAsResponse } from "../../../definitions/PaginatedBranchrestrictionsAsResponse";
import { ErrorAsResponse } from "../../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { BranchrestrictionAsResponse } from "../../../definitions/BranchrestrictionAsResponse";
export interface GetRepositoryBranchRestrictionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    /**
     * Branch restrictions of this type
     */
    kind?: "require_tasks_to_be_completed" | "allow_auto_merge_when_builds_pass" | "require_passing_builds_to_merge" | "force" | "require_all_dependencies_merged" | "restrict_merges" | "enforce_merge_checks" | "reset_pullrequest_changes_requested_on_change" | "require_no_changes_requested" | "smart_reset_pullrequest_approvals" | "push" | "require_approvals_to_merge" | "require_default_reviewer_approvals_to_merge" | "reset_pullrequest_approvals_on_change" | "delete";
    /**
     * Branch restrictions applied to branches of this pattern
     */
    pattern?: string;
}
export interface GetRepositoryBranchRestrictionsResponseOK extends PaginatedBranchrestrictionsAsResponse {
}
export interface GetRepositoryBranchRestrictionsResponseError extends ErrorAsResponse {
}
export interface CreateRepositoryBranchRestrictionRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * The type of restriction that is being applied.
         */
        kind: "require_tasks_to_be_completed" | "allow_auto_merge_when_builds_pass" | "require_passing_builds_to_merge" | "force" | "require_all_dependencies_merged" | "restrict_merges" | "enforce_merge_checks" | "reset_pullrequest_changes_requested_on_change" | "require_no_changes_requested" | "smart_reset_pullrequest_approvals" | "push" | "require_approvals_to_merge" | "require_default_reviewer_approvals_to_merge" | "reset_pullrequest_approvals_on_change" | "delete" | "allow_auto_merge_when_builds_pass" | "require_all_comments_resolved" | "require_commits_behind";
        /**
         * Indicates how the restriction is matched against a branch. The default is `glob`.
         */
        branch_match_kind?: "branching_model" | "glob";
        /**
         * Apply the restriction to branches of this type. Active when `branch_match_kind` is `branching_model`. The branch type will be calculated using the branching model configured for the repository.
         */
        branch_type?: "feature" | "bugfix" | "release" | "hotfix" | "development" | "production";
        /**
         * Apply the restriction to branches that match this pattern. Active when `branch_match_kind` is `glob`. Will be empty when `branch_match_kind` is `branching_model`.
         */
        pattern?: string;
        users?: Array<{
            /**
             * One of username or uuid is required.
             */
            username?: string;
            /**
             * One of username or uuid is required.
             */
            uuid?: string;
        }>;
        groups?: Array<{
            slug: string;
        }>;
        /**
         * Note: Specifying the value parameter on a restriction whose kind does not support non-null values, will throw an error.
         */
        value?: number;
        [x: string]: any;
    };
}
export interface CreateRepositoryBranchRestrictionResponseOK extends BranchrestrictionAsResponse {
}
export interface CreateRepositoryBranchRestrictionResponseError extends ErrorAsResponse {
}
export interface GetRepositoryBranchRestrictionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The restriction rule's id
     */
    id: string | number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryBranchRestrictionResponseOKType = BranchrestrictionAsResponse;
export interface GetRepositoryBranchRestrictionResponseOK extends GetRepositoryBranchRestrictionResponseOKType {
}
declare type GetRepositoryBranchRestrictionResponseErrorType = ErrorAsResponse & ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryBranchRestrictionResponseError extends GetRepositoryBranchRestrictionResponseErrorType {
}
export interface UpdateRepositoryBranchRestrictionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The restriction rule's id
     */
    id: string | number;
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * Indicates how the restriction is matched against a branch. The default is `glob`.
         */
        branch_match_kind?: "branching_model" | "glob";
        /**
         * Apply the restriction to branches of this type. Active when `branch_match_kind` is `branching_model`. The branch type will be calculated using the branching model configured for the repository.
         */
        branch_type?: "feature" | "bugfix" | "release" | "hotfix" | "development" | "production";
        /**
         * Apply the restriction to branches that match this pattern. Active when `branch_match_kind` is `glob`. Will be empty when `branch_match_kind` is `branching_model`.
         */
        pattern?: string;
        /**
         *Note: If this parameter is not provided, all existing users will be removed from the restriction.
         */
        users?: Array<{
            /**
             * One of username or uuid is required.
             */
            username?: string;
            /**
             * One of username or uuid is required.
             */
            uuid?: string;
        }>;
        /**
         * Note: If this parameter is not specified or an empty array is provided, all existing groups will be removed from the restriction.
         */
        groups?: Array<{
            slug: string;
        }>;
        /**
         *Note: Specifying the value parameter on a restriction whose kind does not support non-null values, will throw an error.
         */
        value?: number;
        [x: string]: any;
    };
}
export interface UpdateRepositoryBranchRestrictionResponseOK extends BranchrestrictionAsResponse {
}
export interface UpdateRepositoryBranchRestrictionResponseError extends ErrorAsResponse {
}
export interface DeleteRepositoryBranchRestrictionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The restriction rule's id
     */
    id: string | number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
export declare type DeleteRepositoryBranchRestrictionResponseOK = undefined;
declare type DeleteRepositoryBranchRestrictionResponseErrorType = ErrorAsResponse & ErrorAsResponse & ErrorAsResponse;
export interface DeleteRepositoryBranchRestrictionResponseError extends DeleteRepositoryBranchRestrictionResponseErrorType {
}
export {};
//# sourceMappingURL=restriction.d.ts.map