/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CommitAsResponse } from "../../definitions/CommitAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PaginatedFilesAsResponse } from "../../definitions/PaginatedFilesAsResponse";
import { PaginatedChangesetAsResponse } from "../../definitions/PaginatedChangesetAsResponse";
export interface GetRepositoryCommitRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The commit's SHA1.
     */
    commit: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryCommitResponseOKType = CommitAsResponse;
export interface GetRepositoryCommitResponseOK extends GetRepositoryCommitResponseOKType {
}
declare type GetRepositoryCommitResponseErrorType = ErrorAsResponse;
export interface GetRepositoryCommitResponseError extends GetRepositoryCommitResponseErrorType {
}
export interface GetRepositoryCommitsByFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the branch
     */
    branch: string;
    /**
     * Path to the file.
     */
    path: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  *
  When `true`, Bitbucket will follow the history of the file across
  renames (this is the default behavior). This can be turned off by
  specifying `false`.
  */
    renames?: "false" | "true";
    /**
  *
  Query string to narrow down the response as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
  */
    q?: string;
    /**
  *
  Name of a response property sort the result by as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#sorting-query-results).
  
  */
    sort?: string;
}
declare type GetRepositoryCommitsByFileResponseOKType = PaginatedFilesAsResponse;
export interface GetRepositoryCommitsByFileResponseOK extends GetRepositoryCommitsByFileResponseOKType {
}
declare type GetRepositoryCommitsByFileResponseErrorType = ErrorAsResponse;
export interface GetRepositoryCommitsByFileResponseError extends GetRepositoryCommitsByFileResponseErrorType {
}
export interface GetRepositoryCommitsRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body?: {
        /**
             * Filter results by only returning commits that are present on branches specified with this parameter.
             Can be used in combination with 'exclude' and 'path' parameters.
             */
        include?: string[];
        /**
             * Filter results by only returning commits that are NOT present on branches specified with this parameter.
             Can be used in combination with 'include' and 'path' parameters.
             */
        exclude?: string[];
        /**
             * An optional path parameter can be specified that will limit the results to commits that affect that path.
             path can either be a file or a directory. If a directory is specified,
             commits are returned that have modified any file in the directory tree rooted by path.
             It is important to note that if the path parameter is specified, the commits returned by this endpoint may no longer be a DAG,
             parent commits that do not modify the path will be omitted from the response.
             Can be used in combination with 'include' and 'exclude' parameters.
             */
        path?: string;
    };
}
export interface GetRepositoryCommitsResponseOK extends PaginatedChangesetAsResponse {
}
export interface GetRepositoryCommitsResponseError extends ErrorAsResponse {
}
export {};
//# sourceMappingURL=commit.d.ts.map