/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedCommitstatusesAsResponse } from "../../../definitions/PaginatedCommitstatusesAsResponse";
import { ErrorAsResponse } from "../../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { CommitstatusAsResponse } from "../../../definitions/CommitstatusAsResponse";
export interface GetRepositoryCommitStatusesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The commit's SHA1.
     */
    commit: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  * If specified, only return commit status objects that were either
  created without a refname, or were created with the specified refname
  
  */
    refname?: string;
    /**
  * Query string to narrow down the response as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
   Example:`state="SUCCESSFUL"`
  */
    q?: string;
    /**
  * Field by which the results should be sorted as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
  Defaults to `created_on`.
  
  */
    sort?: string;
}
declare type GetRepositoryCommitStatusesResponseOKType = PaginatedCommitstatusesAsResponse;
export interface GetRepositoryCommitStatusesResponseOK extends GetRepositoryCommitStatusesResponseOKType {
}
declare type GetRepositoryCommitStatusesResponseErrorType = ErrorAsResponse;
export interface GetRepositoryCommitStatusesResponseError extends GetRepositoryCommitStatusesResponseErrorType {
}
export interface CreateRepositoryCommitStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The commit's SHA1.
     */
    commit: string;
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        key: string;
        state: "SUCCESSFUL" | "FAILED" | "INPROGRESS" | "STOPPED";
        /**
             * When creating a new commit status, you can use a URI template for the URL.
             Templates are URLs that contain variable names that Bitbucket will evaluate at runtime
             whenever the URL is displayed anywhere similar to parameter substitution in Bitbucket Connect.
             For example, one could use https://foo.com/builds/{repository.full_name} which Bitbucket will turn into https://foo.com/builds/foo/bar at render time.
             The context variables available are repository and commit.
             */
        url: string;
        description?: string;
        name?: string;
        refname?: string;
    };
}
export interface CreateRepositoryCommitStatusResponseOK extends CommitstatusAsResponse {
}
export interface CreateRepositoryCommitStatusResponseError extends ErrorAsResponse {
}
export interface GetRepositoryCommitStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The commit's SHA1.
     */
    commit: string;
    /**
     * The build status' unique key
     */
    key: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryCommitStatusResponseOKType = CommitstatusAsResponse;
export interface GetRepositoryCommitStatusResponseOK extends GetRepositoryCommitStatusResponseOKType {
}
declare type GetRepositoryCommitStatusResponseErrorType = ErrorAsResponse;
export interface GetRepositoryCommitStatusResponseError extends GetRepositoryCommitStatusResponseErrorType {
}
export {};
//# sourceMappingURL=status.d.ts.map