/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedEnvironmentsAsResponse } from "../../definitions/PaginatedEnvironmentsAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DeploymentEnvironmentAsResponse } from "../../definitions/DeploymentEnvironmentAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
export interface GetRepositoryEnvironmentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
}
declare type GetRepositoryEnvironmentsResponseOKType = PaginatedEnvironmentsAsResponse;
export interface GetRepositoryEnvironmentsResponseOK extends GetRepositoryEnvironmentsResponseOKType {
}
export declare type GetRepositoryEnvironmentsResponseError = undefined;
export interface CreateRepositoryEnvironmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    body: {
        /**
         * The name of the environment.
         */
        name: string;
        environment_type: {
            name: "Test" | "Staging" | "Production";
        };
        deployment_gate_enabled?: boolean;
        hidden?: boolean;
        rank?: number;
        restrictions?: {
            admin_only: boolean;
        };
    };
}
export interface CreateRepositoryEnvironmentResponseOK extends DeploymentEnvironmentAsResponse {
}
export interface CreateRepositoryEnvironmentResponseError extends ErrorAsResponse {
}
export interface GetRepositoryEnvironmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The environment UUID.
     */
    environment_uuid: string;
}
declare type GetRepositoryEnvironmentResponseOKType = DeploymentEnvironmentAsResponse;
export interface GetRepositoryEnvironmentResponseOK extends GetRepositoryEnvironmentResponseOKType {
}
declare type GetRepositoryEnvironmentResponseErrorType = ErrorAsResponse;
export interface GetRepositoryEnvironmentResponseError extends GetRepositoryEnvironmentResponseErrorType {
}
export interface DeleteRepositoryEnvironmentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The environment UUID.
     */
    environment_uuid: string;
}
export declare type DeleteRepositoryEnvironmentResponseOK = undefined;
declare type DeleteRepositoryEnvironmentResponseErrorType = ErrorAsResponse;
export interface DeleteRepositoryEnvironmentResponseError extends DeleteRepositoryEnvironmentResponseErrorType {
}
export {};
//# sourceMappingURL=environment.d.ts.map