/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedDeploymentVariableAsResponse } from "../../../definitions/PaginatedDeploymentVariableAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DeploymentVariableAsResponse } from "../../../definitions/DeploymentVariableAsResponse";
import { ErrorAsResponse } from "../../../definitions/ErrorAsResponse";
export interface GetRepositoryEnvironmentVariablesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The environment.
     */
    environment_uuid: string;
}
declare type GetRepositoryEnvironmentVariablesResponseOKType = PaginatedDeploymentVariableAsResponse;
export interface GetRepositoryEnvironmentVariablesResponseOK extends GetRepositoryEnvironmentVariablesResponseOKType {
}
export declare type GetRepositoryEnvironmentVariablesResponseError = undefined;
export interface CreateRepositoryEnvironmentVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The environment.
     */
    environment_uuid: string;
    body: {
        /**
         * The unique name of the variable.
         */
        key: string;
        /**
         * The value of the variable. If the variable is secured, this will never be shown in the response.
         */
        value: string | number | boolean;
        /**
         * If true, this variable will be treated as secured. The value will never be exposed in the logs or the REST API.
         */
        secured: boolean;
    };
}
export interface CreateRepositoryEnvironmentVariableResponseOK extends DeploymentVariableAsResponse {
}
export interface CreateRepositoryEnvironmentVariableResponseError extends ErrorAsResponse {
}
export interface UpdateRepositoryEnvironmentVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The environment.
     */
    environment_uuid: string;
    /**
     * The UUID of the variable to update.
     */
    variable_uuid: string;
    body: {
        /**
         * The unique name of the variable.
         */
        key?: string;
        /**
         * The value of the variable. If the variable is secured, this will never be shown in the response.
         */
        value?: string | number | boolean;
        /**
         * If true, this variable will be treated as secured. The value will never be exposed in the logs or the REST API.
         */
        secured?: boolean;
    };
}
export interface UpdateRepositoryEnvironmentVariableResponseOK extends DeploymentVariableAsResponse {
}
export interface UpdateRepositoryEnvironmentVariableResponseError extends ErrorAsResponse {
}
export interface DeleteRepositoryEnvironmentVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The environment.
     */
    environment_uuid: string;
    /**
     * The UUID of the variable to delete.
     */
    variable_uuid: string;
}
export declare type DeleteRepositoryEnvironmentVariableResponseOK = undefined;
declare type DeleteRepositoryEnvironmentVariableResponseErrorType = ErrorAsResponse;
export interface DeleteRepositoryEnvironmentVariableResponseError extends DeleteRepositoryEnvironmentVariableResponseErrorType {
}
export {};
//# sourceMappingURL=variable.d.ts.map