/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedRepositoriesAsResponse } from "../../definitions/PaginatedRepositoriesAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { RepositoryAsResponse } from "../../definitions/RepositoryAsResponse";
export interface GetRepositoryForksRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  * Filters the result based on the authenticated user's role on each repository.
  
  * **member**: returns repositories to which the user has explicit read access
  * **contributor**: returns repositories to which the user has explicit write access
  * **admin**: returns repositories to which the user has explicit administrator access
  * **owner**: returns all repositories owned by the current user
  
  */
    role?: "admin" | "contributor" | "member" | "owner";
    /**
  * Query string to narrow down the response as per [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
   Example:`language="javascript"`
  */
    q?: string;
    /**
  * Field by which the results should be sorted as per [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
  
  */
    sort?: string;
}
declare type GetRepositoryForksResponseOKType = PaginatedRepositoriesAsResponse;
export interface GetRepositoryForksResponseOK extends GetRepositoryForksResponseOKType {
}
export declare type GetRepositoryForksResponseError = undefined;
export interface CreateRepositoryForkRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * The project must be assigned for all repositories. If the project is not provided, the repository is automatically assigned to the oldest project in the workspace.
         * If there are no projects present in the workspace, a default one will automatically be created.
         */
        project?: {
            key: string;
        };
        name?: string;
        description?: string;
        has_issues?: boolean;
        has_wiki?: boolean;
        is_private?: boolean;
        fork_policy?: "allow_forks" | "no_public_forks" | "no_forks";
        /**
         * Defaults to the owner's display name. If no workspace exists with such a name, it will be created automatically.
         * In order to fork to the same workspace as the source repository, the name of the new fork must also be specified.
         */
        workspace?: {
            slug: string;
        };
    };
}
export interface CreateRepositoryForkResponseOK extends RepositoryAsResponse {
}
export declare type CreateRepositoryForkResponseError = undefined;
export {};
//# sourceMappingURL=fork.d.ts.map