/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PipelineAsResponse } from "../../definitions/PipelineAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PaginatedPipelinesAsResponse } from "../../definitions/PaginatedPipelinesAsResponse";
export interface CreateAndInitiateRepositoryPipelineRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example: {workspace UUID}.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The pipeline to initiate.
     */
    body: {
        /**
         * The target that the pipeline built.
         */
        target: {
            commit?: {
                type?: string;
                hash: string;
            };
            selector?: {
                type: string;
                pattern: string;
            };
            ref_type?: "branch" | "named_branch" | "bookmark" | "tag";
            type: string;
            ref_name?: string;
            source?: string;
            destination?: string;
            destination_commit?: {
                hash: string;
            };
            pullrequest?: {
                id: string;
            };
        };
        variables?: {
            key: string;
            value: string;
            secured?: boolean;
        }[];
    };
}
export interface CreateAndInitiateRepositoryPipelineResponseOK extends PipelineAsResponse {
}
export interface CreateAndInitiateRepositoryPipelineResponseError extends ErrorAsResponse {
}
export interface FindRepositoryPipelinesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The UUID of the creator of the pipeline to filter by.
     */
    "creator.uuid"?: string;
    /**
     * The type of the reference to filter by.
     */
    "target.ref_type"?: "BRANCH" | "TAG" | "ANNOTATED_TAG";
    /**
     * The reference name to filter by.
     */
    "target.ref_name"?: string;
    /**
     * The name of the branch to filter by.
     */
    "target.branch"?: string;
    /**
     * The revision to filter by.
     */
    "target.commit.hash"?: string;
    /**
     * The pipeline pattern to filter by.
     */
    "target.selector.pattern"?: string;
    /**
     * The type of pipeline to filter by.
     */
    "target.selector.type"?: "BRANCH" | "TAG" | "CUSTOM" | "PULLREQUESTS" | "DEFAULT";
    /**
     * The creation date to filter by.
     */
    created_on?: string;
    /**
     * The trigger type to filter by.
     */
    trigger_type?: "PUSH" | "MANUAL" | "SCHEDULED" | "PARENT_STEP";
    /**
     * The pipeline status to filter by.
     */
    status?: "PARSING" | "PENDING" | "PAUSED" | "HALTED" | "BUILDING" | "ERROR" | "PASSED" | "FAILED" | "STOPPED" | "UNKNOWN";
    /**
     * The attribute name to sort on.
     */
    sort?: "creator.uuid" | "created_on" | "run_creation_date";
    /**
     * The page number of elements to retrieve.
     */
    page?: number;
    /**
     * The maximum number of results to return.
     */
    pagelen?: number;
}
declare type FindRepositoryPipelinesResponseOKType = PaginatedPipelinesAsResponse;
export interface FindRepositoryPipelinesResponseOK extends FindRepositoryPipelinesResponseOKType {
}
export declare type FindRepositoryPipelinesResponseError = undefined;
export interface RetrieveRepositoryPipelineRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The pipeline UUID.
     */
    pipeline_uuid: string;
}
declare type RetrieveRepositoryPipelineResponseOKType = PipelineAsResponse;
export interface RetrieveRepositoryPipelineResponseOK extends RetrieveRepositoryPipelineResponseOKType {
}
declare type RetrieveRepositoryPipelineResponseErrorType = ErrorAsResponse;
export interface RetrieveRepositoryPipelineResponseError extends RetrieveRepositoryPipelineResponseErrorType {
}
export interface StopRepositoryPipelineRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The UUID of the pipeline.
     */
    pipeline_uuid: string;
}
export declare type StopRepositoryPipelineResponseOK = undefined;
declare type StopRepositoryPipelineResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface StopRepositoryPipelineResponseError extends StopRepositoryPipelineResponseErrorType {
}
export {};
//# sourceMappingURL=pipeline.d.ts.map