/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PipelineScheduleAsResponse } from "../../../../definitions/PipelineScheduleAsResponse";
import { ErrorAsResponse } from "../../../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PaginatedPipelineSchedulesAsResponse } from "../../../../definitions/PaginatedPipelineSchedulesAsResponse";
import { PipelineSchedulePutRequestBody } from "../../../../definitions/PipelineSchedulePutRequestBody";
export interface CreateRepositoryPipelineConfigurationScheduleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example: {workspace UUID}.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The schedule to create.
     */
    body: {
        /**
         * Whether the schedule is enabled.
         */
        enabled?: boolean;
        /**
         * The target on which the schedule will be executed.
         */
        target: {
            type: "pipeline_commit_target" | "pipeline_pullrequest_target" | "pipeline_ref_target";
            ref_type: "branch" | "named_branch" | "bookmark" | "tag";
            ref_name: string;
            selector: {
                /**
                 * The type of selector.
                 */
                type: "branches" | "tags" | "bookmarks" | "default" | "custom";
            };
        };
        /**
         * The cron expression that the schedule applies.
         */
        cron_pattern: string;
    };
}
export interface CreateRepositoryPipelineConfigurationScheduleResponseOK extends PipelineScheduleAsResponse {
}
export interface CreateRepositoryPipelineConfigurationScheduleResponseError extends ErrorAsResponse {
}
export interface RetrieveRepositoryPipelineConfigurationSchedulesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
}
declare type RetrieveRepositoryPipelineConfigurationSchedulesResponseOKType = PaginatedPipelineSchedulesAsResponse;
export interface RetrieveRepositoryPipelineConfigurationSchedulesResponseOK extends RetrieveRepositoryPipelineConfigurationSchedulesResponseOKType {
}
declare type RetrieveRepositoryPipelineConfigurationSchedulesResponseErrorType = ErrorAsResponse;
export interface RetrieveRepositoryPipelineConfigurationSchedulesResponseError extends RetrieveRepositoryPipelineConfigurationSchedulesResponseErrorType {
}
export interface UpdateRepositoryPipelineConfigurationScheduleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The uuid of the schedule.
     */
    schedule_uuid: string;
    body: PipelineSchedulePutRequestBody;
}
declare type UpdateRepositoryPipelineConfigurationScheduleResponseOKType = PipelineScheduleAsResponse;
export interface UpdateRepositoryPipelineConfigurationScheduleResponseOK extends UpdateRepositoryPipelineConfigurationScheduleResponseOKType {
}
declare type UpdateRepositoryPipelineConfigurationScheduleResponseErrorType = ErrorAsResponse;
export interface UpdateRepositoryPipelineConfigurationScheduleResponseError extends UpdateRepositoryPipelineConfigurationScheduleResponseErrorType {
}
export interface RetrieveRepositoryPipelineConfigurationScheduleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The uuid of the schedule.
     */
    schedule_uuid: string;
}
declare type RetrieveRepositoryPipelineConfigurationScheduleResponseOKType = PipelineScheduleAsResponse;
export interface RetrieveRepositoryPipelineConfigurationScheduleResponseOK extends RetrieveRepositoryPipelineConfigurationScheduleResponseOKType {
}
declare type RetrieveRepositoryPipelineConfigurationScheduleResponseErrorType = ErrorAsResponse;
export interface RetrieveRepositoryPipelineConfigurationScheduleResponseError extends RetrieveRepositoryPipelineConfigurationScheduleResponseErrorType {
}
export interface DeleteRepositoryPipelineConfigurationScheduleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The uuid of the schedule.
     */
    schedule_uuid: string;
}
export declare type DeleteRepositoryPipelineConfigurationScheduleResponseOK = undefined;
declare type DeleteRepositoryPipelineConfigurationScheduleResponseErrorType = ErrorAsResponse;
export interface DeleteRepositoryPipelineConfigurationScheduleResponseError extends DeleteRepositoryPipelineConfigurationScheduleResponseErrorType {
}
export {};
//# sourceMappingURL=schedule.d.ts.map