/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedPipelineVariablesAsResponse } from "../../../../definitions/PaginatedPipelineVariablesAsResponse";
import { ErrorStrategyOption } from "../../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PipelineVariableAsResponse } from "../../../../definitions/PipelineVariableAsResponse";
import { ErrorAsResponse } from "../../../../definitions/ErrorAsResponse";
export interface GetRepositoryPipelineConfigurationVariablesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
}
declare type GetRepositoryPipelineConfigurationVariablesResponseOKType = PaginatedPipelineVariablesAsResponse;
export interface GetRepositoryPipelineConfigurationVariablesResponseOK extends GetRepositoryPipelineConfigurationVariablesResponseOKType {
}
export declare type GetRepositoryPipelineConfigurationVariablesResponseError = undefined;
export interface CreateRepositoryPipelineConfigurationVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    body: {
        /**
         * The unique name of the variable.
         */
        key: string;
        /**
         * The value of the variable. If the variable is secured, this will never be shown in the response.
         */
        value: string | number | boolean;
        /**
         * If true, this variable will be treated as secured. The value will never be exposed in the logs or the REST API.
         */
        secured: boolean;
    };
}
export interface CreateRepositoryPipelineConfigurationVariableResponseOK extends PipelineVariableAsResponse {
}
export interface CreateRepositoryPipelineConfigurationVariableResponseError extends ErrorAsResponse {
}
export interface GetRepositoryPipelineConfigurationVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The UUID of the variable to retrieve.
     */
    variable_uuid: string;
}
declare type GetRepositoryPipelineConfigurationVariableResponseOKType = PipelineVariableAsResponse;
export interface GetRepositoryPipelineConfigurationVariableResponseOK extends GetRepositoryPipelineConfigurationVariableResponseOKType {
}
declare type GetRepositoryPipelineConfigurationVariableResponseErrorType = ErrorAsResponse;
export interface GetRepositoryPipelineConfigurationVariableResponseError extends GetRepositoryPipelineConfigurationVariableResponseErrorType {
}
export interface UpdateRepositoryPipelineConfigurationVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The UUID of the variable to update.
     */
    variable_uuid: string;
    body: {
        /**
         * The unique name of the variable.
         */
        key?: string;
        /**
         * The value of the variable. If the variable is secured, this will never be shown in the response.
         */
        value?: string | number | boolean;
        /**
         * If true, this variable will be treated as secured. The value will never be exposed in the logs or the REST API.
         */
        secured?: boolean;
    };
}
export interface UpdateRepositoryPipelineConfigurationVariableResponseOK extends PipelineVariableAsResponse {
}
export interface UpdateRepositoryPipelineConfigurationVariableResponseError extends ErrorAsResponse {
}
export interface DeleteRepositoryPipelineConfigurationVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The repository.
     */
    repo_slug: string;
    /**
     * The UUID of the variable to delete.
     */
    variable_uuid: string;
}
export declare type DeleteRepositoryPipelineConfigurationVariableResponseOK = undefined;
declare type DeleteRepositoryPipelineConfigurationVariableResponseErrorType = ErrorAsResponse;
export interface DeleteRepositoryPipelineConfigurationVariableResponseError extends DeleteRepositoryPipelineConfigurationVariableResponseErrorType {
}
export {};
//# sourceMappingURL=variable.d.ts.map