/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedPullrequestsAsResponse } from "../../definitions/PaginatedPullrequestsAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PullrequestAsResponse } from "../../definitions/PullrequestAsResponse";
import { ParticipantAsResponse } from "../../definitions/ParticipantAsResponse";
import { PaginatedCommitstatusesAsResponse } from "../../definitions/PaginatedCommitstatusesAsResponse";
export interface GetRepositoryPullrequestsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
     * Only return pull requests that are in this state. This parameter can be repeated.
     */
    state?: "OPEN" | "MERGED" | "DECLINED" | "SUPERSEDED";
}
declare type GetRepositoryPullrequestsResponseOKType = PaginatedPullrequestsAsResponse;
export interface GetRepositoryPullrequestsResponseOK extends GetRepositoryPullrequestsResponseOKType {
}
declare type GetRepositoryPullrequestsResponseErrorType = ErrorAsResponse;
export interface GetRepositoryPullrequestsResponseError extends GetRepositoryPullrequestsResponseErrorType {
}
export interface CreateRepositoryPullrequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    /**
       * The new pull request.
       The request URL you POST to becomes the destination repository URL. For this reason, you must specify an explicit source repository in the request object if you want to pull from a different repository (fork).
       Since not all elements are required or even mutable, you only need to include the elements you want to initialize, such as the source branch and the title.
       */
    body: {
        /**
         * Title of the pull request.
         */
        title: string;
        description?: string;
        source: {
            branch: {
                name: string;
            };
        };
        destination?: {
            branch: {
                name: string;
            };
        };
        /**
         * A boolean flag indicating if merging the pull request closes the source branch.
         */
        close_source_branch?: boolean;
        /**
         * The list of users that were added as reviewers on this pull request when it was created. For performance reasons, the API only includes this list on a pull request's `self` URL.
         */
        reviewers?: {
            uuid: string;
        }[];
    };
}
export interface CreateRepositoryPullrequestResponseOK extends PullrequestAsResponse {
}
export interface CreateRepositoryPullrequestResponseError extends ErrorAsResponse {
}
export interface GetRepositoryPullrequestActivityLogRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
export declare type GetRepositoryPullrequestActivityLogResponseOK = undefined;
declare type GetRepositoryPullrequestActivityLogResponseErrorType = ErrorAsResponse;
export interface GetRepositoryPullrequestActivityLogResponseError extends GetRepositoryPullrequestActivityLogResponseErrorType {
}
export interface GetRepositoryPullrequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryPullrequestResponseOKType = PullrequestAsResponse;
export interface GetRepositoryPullrequestResponseOK extends GetRepositoryPullrequestResponseOKType {
}
declare type GetRepositoryPullrequestResponseErrorType = ErrorAsResponse;
export interface GetRepositoryPullrequestResponseError extends GetRepositoryPullrequestResponseErrorType {
}
export interface MutateRepositoryPullrequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    /**
     * The pull request that is to be updated.
     */
    body: {
        /**
         * Title of the pull request.
         */
        title: string;
        description?: string;
        source?: {
            branch: {
                name: string;
            };
        };
        destination?: {
            branch: {
                name: string;
            };
        };
        /**
         * A boolean flag indicating if merging the pull request closes the source branch.
         */
        close_source_branch?: boolean;
        /**
         * The list of users that were added as reviewers on this pull request when it was created. For performance reasons, the API only includes this list on a pull request's `self` URL.
         */
        reviewers?: {
            uuid: string;
        }[];
    };
}
export interface MutateRepositoryPullrequestResponseOK extends PullrequestAsResponse {
}
export interface MutateRepositoryPullrequestResponseError extends ErrorAsResponse {
}
export interface ApproveRepositoryPullrequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type ApproveRepositoryPullrequestResponseOKType = ParticipantAsResponse;
export interface ApproveRepositoryPullrequestResponseOK extends ApproveRepositoryPullrequestResponseOKType {
}
declare type ApproveRepositoryPullrequestResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface ApproveRepositoryPullrequestResponseError extends ApproveRepositoryPullrequestResponseErrorType {
}
export interface DeclineRepositoryPullrequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type DeclineRepositoryPullrequestResponseOKType = PullrequestAsResponse;
export interface DeclineRepositoryPullrequestResponseOK extends DeclineRepositoryPullrequestResponseOKType {
}
declare type DeclineRepositoryPullrequestResponseErrorType = ErrorAsResponse;
export interface DeclineRepositoryPullrequestResponseError extends DeclineRepositoryPullrequestResponseErrorType {
}
export interface MergeRepositoryPullrequestRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    async: boolean;
    body: {
        type: string;
        /**
         * The commit message that will be used on the resulting commit.
         */
        message?: string;
        /**
         * Whether the source branch should be deleted. If this is not provided, we fallback to the value used when the pull request was created, which defaults to False
         */
        close_source_branch?: boolean;
        /**
         * The merge strategy that will be used to merge the pull request.
         */
        merge_strategy?: "merge_commit" | "squash" | "fast_forward";
    };
}
export declare type MergeRepositoryPullrequestResponseOK = undefined;
export interface MergeRepositoryPullrequestResponseError extends ErrorAsResponse {
}
export interface GetRepositoryPullrequestStatusesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  * Query string to narrow down the response as per
  [filtering and sorting](../../../../../../meta/filtering).
   Example:`state="SUCCESSFUL"`
  */
    q?: string;
    /**
  * Field by which the results should be sorted as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
  Defaults to `created_on`.
  
  */
    sort?: string;
}
declare type GetRepositoryPullrequestStatusesResponseOKType = PaginatedCommitstatusesAsResponse;
export interface GetRepositoryPullrequestStatusesResponseOK extends GetRepositoryPullrequestStatusesResponseOKType {
}
declare type GetRepositoryPullrequestStatusesResponseErrorType = ErrorAsResponse;
export interface GetRepositoryPullrequestStatusesResponseError extends GetRepositoryPullrequestStatusesResponseErrorType {
}
export {};
//# sourceMappingURL=pullrequest.d.ts.map