/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedPullrequestCommentsAsResponse } from "../../../definitions/PaginatedPullrequestCommentsAsResponse";
import { ErrorAsResponse } from "../../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PullrequestCommentAsResponse } from "../../../definitions/PullrequestCommentAsResponse";
export interface GetRepositoryPullrequestCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryPullrequestCommentsResponseOKType = PaginatedPullrequestCommentsAsResponse;
export interface GetRepositoryPullrequestCommentsResponseOK extends GetRepositoryPullrequestCommentsResponseOKType {
}
declare type GetRepositoryPullrequestCommentsResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryPullrequestCommentsResponseError extends GetRepositoryPullrequestCommentsResponseErrorType {
}
export interface CreateRepositoryPullrequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
      * This can either be the repository slug or the UUID of the repository,
      surrounded by curly-braces, for example: `{repository UUID}`.
      */
    repo_slug: string;
    /**
      * This can either be the workspace ID (slug) or the workspace UUID
      surrounded by curly-braces, for example: `{workspace UUID}`.
      */
    workspace: string;
    /**
     * The comment object.
     */
    body: {
        content: {
            /**
             * The text as it was typed by a user.
             */
            raw: string;
        };
    };
}
export interface CreateRepositoryPullrequestCommentResponseOK extends PullrequestCommentAsResponse {
}
export interface CreateRepositoryPullrequestCommentResponseError extends ErrorAsResponse {
}
export interface DeleteRepositoryPullrequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the comment.
     */
    comment_id: number;
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
export declare type DeleteRepositoryPullrequestCommentResponseOK = undefined;
declare type DeleteRepositoryPullrequestCommentResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface DeleteRepositoryPullrequestCommentResponseError extends DeleteRepositoryPullrequestCommentResponseErrorType {
}
export interface GetRepositoryPullrequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the comment.
     */
    comment_id: number;
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryPullrequestCommentResponseOKType = PullrequestCommentAsResponse;
export interface GetRepositoryPullrequestCommentResponseOK extends GetRepositoryPullrequestCommentResponseOKType {
}
declare type GetRepositoryPullrequestCommentResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryPullrequestCommentResponseError extends GetRepositoryPullrequestCommentResponseErrorType {
}
export interface UpdateRepositoryPullrequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the comment.
     */
    comment_id: number;
    /**
     * The id of the pull request.
     */
    pull_request_id: number;
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    /**
     * The contents of the updated comment.
     */
    body: {
        content: {
            /**
             * The text as it was typed by a user.
             */
            raw: string;
        };
    };
}
export interface UpdateRepositoryPullrequestCommentResponseOK extends PullrequestCommentAsResponse {
}
export interface UpdateRepositoryPullrequestCommentResponseError extends ErrorAsResponse {
}
export {};
//# sourceMappingURL=comment.d.ts.map