/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedTagsAsResponse } from "../../definitions/PaginatedTagsAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { TagAsResponse } from "../../definitions/TagAsResponse";
export interface GetRepositoryTagsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
    /**
  *
  Query string to narrow down the response as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering).
   Example:`target.hash="1e9e09996d3f636c7254942bdaf15c4fcd4f0fd4"`
  */
    q?: string;
    /**
  *
  Field by which the results should be sorted as per
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering). The `name`
  field is handled specially for tags in that, if specified as the sort field, it
  uses a natural sort order instead of the default lexicographical sort order. For example,
  it will return ['1.1', '1.2', '1.10'] instead of ['1.1', '1.10', '1.2'].
  */
    sort?: string;
}
declare type GetRepositoryTagsResponseOKType = PaginatedTagsAsResponse;
export interface GetRepositoryTagsResponseOK extends GetRepositoryTagsResponseOKType {
}
declare type GetRepositoryTagsResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryTagsResponseError extends GetRepositoryTagsResponseErrorType {
}
export interface CreateRepositoryTagRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the repository slug or the UUID of the repository,
       surrounded by curly-braces, for example: `{repository UUID}`.
       */
    repo_slug: string;
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        /**
         * The target commit.
         */
        target: {
            /**
                   * This endpoint does support using short hash prefixes for the commit hash,
                   but it may return a 400 response if the provided prefix is ambiguous.
                   Using a full commit hash is the preferred approach.
                   */
            hash: string;
        };
        /**
         * The name of the tag.
         */
        name: string;
        /**
         * The message associated with the tag. If emitted, a default message will be added automatically.
         */
        message?: string;
    };
}
export interface CreateRepositoryTagResponseOK extends TagAsResponse {
}
export interface CreateRepositoryTagResponseError extends ErrorAsResponse {
}
export interface GetRepositoryTagRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the tag.
     */
    name: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetRepositoryTagResponseOKType = TagAsResponse;
export interface GetRepositoryTagResponseOK extends GetRepositoryTagResponseOKType {
}
declare type GetRepositoryTagResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface GetRepositoryTagResponseError extends GetRepositoryTagResponseErrorType {
}
export interface DeleteRepositoryTagRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The name of the tag.
     */
    name: string;
    /**
  * This can either be the repository slug or the UUID of the repository,
  surrounded by curly-braces, for example: `{repository UUID}`.
  
  */
    repo_slug: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
export declare type DeleteRepositoryTagResponseOK = undefined;
declare type DeleteRepositoryTagResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface DeleteRepositoryTagResponseError extends DeleteRepositoryTagResponseErrorType {
}
export {};
//# sourceMappingURL=tag.d.ts.map