/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedSshUserKeysAsResponse } from "../../definitions/PaginatedSshUserKeysAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { SshAccountKeyAsResponse } from "../../definitions/SshAccountKeyAsResponse";
export interface GetUserSSHKeysRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be an Atlassian Account ID OR the UUID of the account,
  surrounded by curly-braces, for example: `{account UUID}`.
  
  */
    selected_user: string;
}
declare type GetUserSSHKeysResponseOKType = PaginatedSshUserKeysAsResponse;
export interface GetUserSSHKeysResponseOK extends GetUserSSHKeysResponseOKType {
}
declare type GetUserSSHKeysResponseErrorType = ErrorAsResponse;
export interface GetUserSSHKeysResponseError extends GetUserSSHKeysResponseErrorType {
}
export interface AddUserSSHKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the UUID of the account, surrounded by curly-braces, for
       example: `{account UUID}`, OR an Atlassian Account ID.
      */
    selected_user: string;
    body: {
        /**
         * The SSH public key value in OpenSSH format.
         */
        key: string;
        /**
         * The user-defined label for the SSH key
         */
        label?: string;
    };
}
export interface AddUserSSHKeyResponseOK extends SshAccountKeyAsResponse {
}
export declare type AddUserSSHKeyResponseError = ErrorAsResponse | undefined;
export interface GetUserSSHKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The SSH key's UUID value.
     */
    key_id: string;
    /**
  * This can either be an Atlassian Account ID OR the UUID of the account,
  surrounded by curly-braces, for example: `{account UUID}`.
  
  */
    selected_user: string;
}
declare type GetUserSSHKeyResponseOKType = SshAccountKeyAsResponse;
export interface GetUserSSHKeyResponseOK extends GetUserSSHKeyResponseOKType {
}
declare type GetUserSSHKeyResponseErrorType = ErrorAsResponse;
export interface GetUserSSHKeyResponseError extends GetUserSSHKeyResponseErrorType {
}
export interface UpdateUserSSHKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The SSH key's UUID value.
     */
    key_id: string;
    /**
       * This can either be the UUID of the account, surrounded by curly-braces, for
       example: `{account UUID}`, OR an Atlassian Account ID.
       */
    selected_user: string;
    body: {
        /**
         * The user-defined label for the SSH key
         */
        label?: string;
    };
}
export interface UpdateUserSSHKeyResponseOK extends SshAccountKeyAsResponse {
}
export declare type UpdateUserSSHKeyResponseError = ErrorAsResponse | undefined;
export interface DeleteUserSSHKeyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The SSH key's UUID value.
     */
    key_id: string;
    /**
  * This can either be an Atlassian Account ID OR the UUID of the account,
  surrounded by curly-braces, for example: `{account UUID}`.
  
  */
    selected_user: string;
}
export declare type DeleteUserSSHKeyResponseOK = undefined;
declare type DeleteUserSSHKeyResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface DeleteUserSSHKeyResponseError extends DeleteUserSSHKeyResponseErrorType {
}
export {};
//# sourceMappingURL=ssh.d.ts.map