/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedWorkspacesAsResponse } from "../definitions/PaginatedWorkspacesAsResponse";
import { ErrorAsResponse } from "../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { WorkspaceAsResponse } from "../definitions/WorkspaceAsResponse";
export interface GetWorkspacesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  *
              Filters the workspaces based on the authenticated user's role on each workspace.
  
              * **member**: returns a list of all the workspaces which the caller is a member of
                  at least one workspace group or repository
              * **collaborator**: returns a list of workspaces which the caller has write access
                  to at least one repository in the workspace
              * **owner**: returns a list of workspaces which the caller has administrator access
              
  */
    role?: "owner" | "collaborator" | "member";
    /**
  *
  Query string to narrow down the response. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#filtering) for details.
  */
    q?: string;
    /**
  *
  Name of a response property to sort results. See
  [filtering and sorting](/cloud/bitbucket/rest/intro/#sorting-query-results)
  for details.
  
  */
    sort?: string;
}
declare type GetWorkspacesResponseOKType = PaginatedWorkspacesAsResponse;
export interface GetWorkspacesResponseOK extends GetWorkspacesResponseOKType {
}
declare type GetWorkspacesResponseErrorType = ErrorAsResponse;
export interface GetWorkspacesResponseError extends GetWorkspacesResponseErrorType {
}
export interface GetWorkspaceRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetWorkspaceResponseOKType = WorkspaceAsResponse;
export interface GetWorkspaceResponseOK extends GetWorkspaceResponseOKType {
}
declare type GetWorkspaceResponseErrorType = ErrorAsResponse;
export interface GetWorkspaceResponseError extends GetWorkspaceResponseErrorType {
}
export {};
//# sourceMappingURL=workspace.d.ts.map