/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedProjectsAsResponse } from "../../definitions/PaginatedProjectsAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ProjectAsResponse } from "../../definitions/ProjectAsResponse";
export interface GetWorkspaceProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetWorkspaceProjectsResponseOKType = PaginatedProjectsAsResponse;
export interface GetWorkspaceProjectsResponseOK extends GetWorkspaceProjectsResponseOKType {
}
declare type GetWorkspaceProjectsResponseErrorType = ErrorAsResponse;
export interface GetWorkspaceProjectsResponseError extends GetWorkspaceProjectsResponseErrorType {
}
export interface CreateWorkspaceProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
       * This can either be the workspace ID (slug) or the workspace UUID
       surrounded by curly-braces, for example: `{workspace UUID}`.
       */
    workspace: string;
    body: {
        links?: {
            avatar?: {
                href: string;
            };
        };
        /**
         * The project's key.
         */
        key: string;
        /**
         * The name of the project.
         */
        name: string;
        description?: string;
        /**
            *
            Indicates whether the project is publicly accessible, or whether it is
            private to the team and consequently only visible to team members.
            Note that private projects cannot contain public repositories.
            */
        is_private: boolean;
    };
}
export interface CreateWorkspaceProjectResponseOK extends ProjectAsResponse {
}
export interface CreateWorkspaceProjectResponseError extends ErrorAsResponse {
}
export interface DeleteWorkspaceProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The project in question. This is the actual `key` assigned
  to the project.
  
  */
    project_key: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
export declare type DeleteWorkspaceProjectResponseOK = undefined;
declare type DeleteWorkspaceProjectResponseErrorType = ErrorAsResponse & ErrorAsResponse;
export interface DeleteWorkspaceProjectResponseError extends DeleteWorkspaceProjectResponseErrorType {
}
export interface GetWorkspaceProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The project in question. This is the actual `key` assigned
  to the project.
  
  */
    project_key: string;
    /**
  * This can either be the workspace ID (slug) or the workspace UUID
  surrounded by curly-braces, for example: `{workspace UUID}`.
  
  */
    workspace: string;
}
declare type GetWorkspaceProjectResponseOKType = ProjectAsResponse;
export interface GetWorkspaceProjectResponseOK extends GetWorkspaceProjectResponseOKType {
}
declare type GetWorkspaceProjectResponseErrorType = ErrorAsResponse & ErrorAsResponse & ErrorAsResponse;
export interface GetWorkspaceProjectResponseError extends GetWorkspaceProjectResponseErrorType {
}
export {};
//# sourceMappingURL=project.d.ts.map