/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PaginatedPipelineVariablesAsResponse } from "../../definitions/PaginatedPipelineVariablesAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PipelineVariableAsResponse } from "../../definitions/PipelineVariableAsResponse";
import { ErrorAsResponse } from "../../definitions/ErrorAsResponse";
export interface GetWorkspaceVariablesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
}
declare type GetWorkspaceVariablesResponseOKType = PaginatedPipelineVariablesAsResponse;
export interface GetWorkspaceVariablesResponseOK extends GetWorkspaceVariablesResponseOKType {
}
export declare type GetWorkspaceVariablesResponseError = undefined;
export interface CreateWorkspaceVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    body: {
        /**
         * The unique name of the variable.
         */
        key: string;
        /**
         * The value of the variable. If the variable is secured, this will never be shown in the response.
         */
        value: string | number | boolean;
        /**
         * If true, this variable will be treated as secured. The value will never be exposed in the logs or the REST API.
         */
        secured: boolean;
    };
}
export interface CreateWorkspaceVariableResponseOK extends PipelineVariableAsResponse {
}
export interface CreateWorkspaceVariableResponseError extends ErrorAsResponse {
}
export interface GetWorkspaceVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The UUID of the variable to retrieve.
     */
    variable_uuid: string;
}
declare type GetWorkspaceVariableResponseOKType = PipelineVariableAsResponse;
export interface GetWorkspaceVariableResponseOK extends GetWorkspaceVariableResponseOKType {
}
declare type GetWorkspaceVariableResponseErrorType = ErrorAsResponse;
export interface GetWorkspaceVariableResponseError extends GetWorkspaceVariableResponseErrorType {
}
export interface UpdateWorkspaceVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The UUID of the variable.
     */
    variable_uuid: string;
    body: {
        /**
         * The unique name of the variable.
         */
        key?: string;
        /**
         * The value of the variable. If the variable is secured, this will never be shown in the response.
         */
        value?: string | number | boolean;
        /**
         * If true, this variable will be treated as secured. The value will never be exposed in the logs or the REST API.
         */
        secured?: boolean;
    };
}
export interface UpdateWorkspaceVariableResponseOK extends PipelineVariableAsResponse {
}
export interface UpdateWorkspaceVariableResponseError extends ErrorAsResponse {
}
export interface DeleteWorkspaceVariableRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This can either be the workspace ID (slug) or the workspace UUID surrounded by curly-braces, for example `{workspace UUID}`.
     */
    workspace: string;
    /**
     * The UUID of the variable to delete.
     */
    variable_uuid: string;
}
export declare type DeleteWorkspaceVariableResponseOK = undefined;
declare type DeleteWorkspaceVariableResponseErrorType = ErrorAsResponse;
export interface DeleteWorkspaceVariableResponseError extends DeleteWorkspaceVariableResponseErrorType {
}
export {};
//# sourceMappingURL=variable.d.ts.map